@@ -627,7 +627,13 @@ Diversity_profile <- function(x,q){
         length(x) + (n-1)/n*ifelse(f2>0, f1^2/2/f2, f1*(f1-1)/2)
       }else if(q==1){
         A <- sum(tab*sortx/n*(digamma(n)-digamma(sortx)))
-        B <- TD1_2nd(n,f1,f2)
+        
+        if(is.infinite((1-p1)^(1-n))){
+          B <- 0
+        }else{
+          B <- TD1_2nd(n,f1,f2)
+        }
+
         exp(A+B)
       }else if(abs(q-round(q))==0){
         A <- sum(tab[sortx>=q]*exp(lchoose(sortx[sortx>=q],q)-lchoose(n,q)))
@@ -639,7 +645,11 @@ Diversity_profile <- function(x,q){
     if(length(q_part1)>0){
       ans[q_part1] <- sapply(q[q_part1], Sub_q012)
       
-      if (sum(x == 1) == length(x) & sum(q %in% 2) > 0) ans[which(q==2)] = TDq(ifi = cbind(i = sortx, fi = tab),n = n,qs = 1.99,f1 = f1,A = p1)
+      
+      
+      if (sum(x == 1) == length(x) & sum(q %in% 2) > 0){
+        ans[which(q==2)] = TDq(ifi = cbind(i = sortx, fi = tab),n = n,qs = 1.99,f1 = f1,A = p1)
+      } 
     }
     q_part2 <- which(!abs(q-round(q))==0)
     if(length(q_part2)>0){
@@ -674,13 +684,23 @@ Diversity_profile.inc <- function(data,q){
     }
     
     Q0hat <- ifelse(Q2 == 0, (nT - 1) / nT * Q1 * (Q1 - 1) / 2, (nT - 1) / nT * Q1 ^ 2/ 2 / Q2)
-    B <- sapply(q,function(q) ifelse(A==1,0,(Q1/nT)*(1-A)^(-nT+1)*round((A^(q-1)-sum(sapply(c(0:(nT-1)),function(r) choose(q-1,r)*(A-1)^r))), 12)))
+    B <- sapply(q,function(q)  
+      
+    if(is.infinite((1-A)^(1-nT))){
+     0
+    }else{
+     ifelse(A==1,0,(Q1/nT)*(1-A)^(-nT+1)*round((A^(q-1)-sum(sapply(c(0:(nT-1)),function(r) choose(q-1,r)*(A-1)^r))), 12))
+    })
+    
     qD <- (U/nT)^(q/(q-1))*(qTDFUN(q,Yi,nT) + B)^(1/(1-q))
     qD[which(q==0)] = Sobs+Q0hat
     
     if (sum(Yi == 1) == length(Yi) & sum(q %in% 2) > 0) {
       for_q2 = 1.99
-      B_forq2 <- sapply(for_q2,function(q) ifelse(A==1,0,(Q1/nT)*(1-A)^(-nT+1)*round((A^(q-1)-sum(sapply(c(0:(nT-1)),function(r) choose(q-1,r)*(A-1)^r))), 12)))
+      B_forq2 <- sapply(for_q2,function(q) 
+        
+     ifelse(A==1|is.infinite((1-A)^(1-nT)),0,(Q1/nT)*(1-A)^(-nT+1)*round((A^(q-1)-sum(sapply(c(0:(nT-1)),function(r) choose(q-1,r)*(A-1)^r))), 12))
+      )
       qD[which(q==2)] <- (U/nT)^(for_q2/(for_q2-1))*(qTDFUN(for_q2,Yi,nT) + B_forq2)^(1/(1-for_q2))
     }
     
@@ -689,7 +709,7 @@ Diversity_profile.inc <- function(data,q){
       (yi[i]/nT)*sum(1/c(yi[i]:(nT-1)))
     }
     if(sum(q %in% 1)>0){
-      C_ <- ifelse(A==1,0,(Q1/nT)*(1-A)^(-nT+1)*(-log(A)-sum(sapply(c(1:(nT-1)),function(r) (1-A)^r/r))))
+      C_ <- ifelse(A==1|is.infinite((1-A)^(1-nT)),0,(Q1/nT)*(1-A)^(-nT+1)*(-log(A)-sum(sapply(c(1:(nT-1)),function(r) (1-A)^r/r))))
       
       if (length(yi) != 0) qD[which(q==1)] <- exp((nT/U)*( sum(sapply(c(1:length(yi)),function(i) delta(i))) + C_)+log(U/nT)) else 
         qD[which(q==1)] <- Diversity_profile_MLE.inc(data, 1)
